@@ -2047,7 +2047,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.filename = None
         self.fileListWidget.clear()
 
-        if self.xllabel.image_root is None:  # ckz，我要扩展一个读取json来展示图片的功能
+        if self.xllabel.image_root is None:
             for filename in self.scanAllImages(dirpath):
                 if pattern and pattern not in filename:
                     continue
@@ -2064,7 +2064,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 else:
                     item.setCheckState(Qt.Unchecked)
                 self.fileListWidget.addItem(item)
-        else:
+        else:  # ckz，我要扩展一个读取json来展示图片的功能
             root = self.xllabel.image_root
             for label_file in XlPath(dirpath).rglob('*.json'):
                 data = label_file.read_json()
